@@ -843,7 +843,7 @@ class ConcurrentRotatingFileHandlerWithBufferInitiativeWindwos(ConcurrentRotatin
             for hr in cls.file_handler_list:
                 # very_nb_print(hr.buffer_msgs_queue.qsize())
                 hr.rollover_and_do_write()
-            time.sleep(0.1)
+            time.sleep(1)
 
     @classmethod
     def start_emit_all_file_handler(cls):
@@ -857,7 +857,7 @@ class ConcurrentRotatingFileHandlerWithBufferInitiativeWindwos(ConcurrentRotatin
         self.file_handler_list.append(self)
         if not self.has_start_emit_all_file_handler:
             self.start_emit_all_file_handler()
-            self.__class__.has_start_emit_all_file_handler = False
+            self.__class__.has_start_emit_all_file_handler = True
 
     def _when_exit(self):
         pass
